
# django-upman

django-upman is a django app for managing file uploads. It provides the
functionality necessary to implement a media library which the end user can
manage on their own. This is similar to WordPress's Media Library.

The project is currently under development and more features will be added.

